import json

from flask import Blueprint, Response, jsonify
from lxml import etree
from inventory_provider import juniper
from inventory_provider.routes import common

routes = Blueprint('poller-support-routes', __name__)


@routes.route('/interfaces/<hostname>', methods=['GET', 'POST'])
@common.require_accepts_json
def poller_interface_oids(hostname):
    r = common.redis_connection()

    netconf_string = r.hget(hostname, 'netconf')
    if not netconf_string:
        return Response(
            response='no netconf available info for %r' % hostname,
            status=404,
            mimetype='text/html')

    snmp_data_string = r.hget(hostname, 'snmp-interfaces')
    if not snmp_data_string:
        return Response(
            response='no snmp available info for '%r % hostname,
            status=404,
            mimetype='text/html')

    def _ifc_name(ifc):
        if 'v4InterfaceName' in ifc:
            return ifc['v4InterfaceName']
        if 'v6InterfaceName' in ifc:
            return ifc['v6InterfaceName']
        assert False, 'sanity failure: no interface name found'

    snmp_indexes = dict([
        (_ifc_name(ifc), int(ifc['index'])) for ifc in
        json.loads(snmp_data_string.decode('utf-8'))
    ])

    interfaces = list(juniper.list_interfaces(
        etree.XML(netconf_string.decode('utf-8'))))

    if not interfaces:
        return Response(
            response='no interfaces found for %r' % hostname,
            status=404,
            mimetype='text/html')

    result = []
    for ifc in interfaces:
        if not ifc['description']:
            continue

        ifc_data = {
            'name': ifc['name'],
            'snmp-index': snmp_indexes.get(ifc['name'], None),
            'description': ifc['description'],
            'circuits': []
        }

        circuits = r.hget(
            'interface_services', '%s::%s' % (hostname, ifc['name']))
        if circuits:
            ifc_data['circuits'] = [
                {'type': c['circuit_type'], 'id': c['id']}
                for c in json.loads(circuits.decode('utf-8'))

            ]

        result.append(ifc_data)

    return jsonify(result)
